==> qore-xml-module-1.3.tar.bz2: qore-xml-module-1.3/docs/WSDL/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore WSDL Module Reference", "index.html", [
    [ "WSDL Module", "index.html", [
      [ "Introduction to the WSDL Module", "index.html#wsdlintro", null ],
      [ "WSDL Module Release Notes", "index.html#wsdlrelnotes", [
        [ "WSDL v0.3.5", "index.html#wsdl_0_3_5", null ],
        [ "WSDL v0.3.4", "index.html#wsdl_0_3_4", null ],
        [ "WSDL v0.3.3", "index.html#wsdl_0_3_3", null ],
        [ "WSDL v0.3.2", "index.html#wsdl_0_3_2", null ],
        [ "WSDL v0.3.1", "index.html#wsdl_0_3_1", null ],
        [ "WSDL v0.3.0", "index.html#wsdl_0_3_0", null ],
        [ "WSDL v0.2.0", "index.html#wsdl_0_2_0", null ]
      ] ]
    ] ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-xml-module-1.4.1.tar.bz2: qore-xml-module-1.4.1/docs/WSDL/html/navtreedata.js <==
var NAVTREE =
[
  [ "Qore WSDL Module Reference", "index.html", [
    [ "WSDL Module", "index.html", [
      [ "Introduction to the WSDL Module", "index.html#wsdlintro", null ],
      [ "WSDL Module Release Notes", "index.html#wsdlrelnotes", [
        [ "WSDL v0.3.7", "index.html#wsdl_0_3_7", null ],
        [ "WSDL v0.3.6", "index.html#wsdl_0_3_6", null ],
        [ "WSDL v0.3.5.1", "index.html#wsdl_0_3_5_1", null ],
        [ "WSDL v0.3.5", "index.html#wsdl_0_3_5", null ],
        [ "WSDL v0.3.4", "index.html#wsdl_0_3_4", null ],
        [ "WSDL v0.3.3", "index.html#wsdl_0_3_3", null ],
        [ "WSDL v0.3.2", "index.html#wsdl_0_3_2", null ],
        [ "WSDL v0.3.1", "index.html#wsdl_0_3_1", null ],
        [ "WSDL v0.3.0", "index.html#wsdl_0_3_0", null ],
        [ "WSDL v0.2.0", "index.html#wsdl_0_2_0", null ]
      ] ]
    ] ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
